@@ -23,9 +23,9 @@ try:
 except:
     from obspy.fdsn import Client as Client_fdsn
 try:
-    from obspy.clients.arclink import Client as Client_arclink
+    from obspy.clients.fdsn import RoutingClient
 except:
-    from obspy.arclink import Client as Client_arclink
+    print("[WARNING] RoutingClient could not be imported.")
 from obspy.clients.syngine import Client as Client_syngine
 try:
     from obspy.geodetics.base import gps2dist_azimuth as gps2DistAzimuth
@@ -34,6 +34,7 @@ except:
         from obspy.geodetics import gps2DistAzimuth
     except:
         from obspy.core.util import gps2DistAzimuth
+from obspy import read_inventory
 import os
 import pickle
 
@@ -48,7 +49,7 @@ warnings.filterwarnings("ignore", category=DeprecationWarning)
 
 def get_data(stas_avail, event, input_dics, info_event):
     """
-    get the waveform/response from FDSN and ArcLink
+    get the waveform/response from FDSN
     :param stas_avail:
     :param event:
     :param input_dics:
@@ -70,18 +71,12 @@ def get_data(stas_avail, event, input_dics, info_event):
         par_jobs = []
         for req_cli in req_clients:
             st_avail = stas_avail[stas_avail[:, 8] == req_cli]
-            if not req_cli.lower() in ['arclink']:
-                p = multiprocessing.Process(target=fdsn_waveform,
-                                            args=(st_avail, event,
-                                                  input_dics, req_cli,
-                                                  info_event))
-                par_jobs.append(p)
-            elif req_cli.lower() == 'arclink':
-                p = multiprocessing.Process(target=arc_waveform,
-                                            args=(st_avail, event,
-                                                  input_dics, req_cli,
-                                                  info_event))
-                par_jobs.append(p)
+
+            p = multiprocessing.Process(target=fdsn_waveform,
+                                        args=(st_avail, event,
+                                                input_dics, req_cli,
+                                                info_event))
+            par_jobs.append(p)
 
         sub_par_jobs = []
         for l in range(len(par_jobs)):
@@ -103,10 +98,7 @@ def get_data(stas_avail, event, input_dics, info_event):
     else:
         for req_cli in req_clients:
             st_avail = stas_avail[stas_avail[:, 8] == req_cli]
-            if not req_cli.lower() in ['arclink']:
-                fdsn_waveform(st_avail, event, input_dics, req_cli, info_event)
-            elif req_cli.lower() == 'arclink':
-                arc_waveform(st_avail, event, input_dics, req_cli, info_event)
+            fdsn_waveform(st_avail, event, input_dics, req_cli, info_event)
 
     print("\n========================")
     print("DONE with Event: %s" % event['event_id'])
@@ -164,10 +156,13 @@ def fdsn_serial_parallel(stas_avail, event, input_dics, target_path,
     """
     print('%s -- event: %s' % (req_cli, target_path))
 
-    client_fdsn = Client_fdsn(base_url=req_cli,
-                              user=input_dics['username_fdsn'],
-                              password=input_dics['password_fdsn'])
-                              #debug=True)
+    if req_cli.lower() in ["iris-federator", "eida-routing"]:
+        client_fdsn = RoutingClient(req_cli)
+    else:
+        client_fdsn = Client_fdsn(base_url=req_cli,
+                                  user=input_dics['username_fdsn'],
+                                  password=input_dics['password_fdsn'])
+                                  #debug=True)
     client_syngine = Client_syngine()
 
     if input_dics['req_parallel']:
@@ -310,12 +305,29 @@ def fdsn_download_core(st_avail, event, input_dics, target_path,
             dummy = 'waveform'
             if (not os.path.isfile(os.path.join(target_path, 'raw', st_id)))\
                     or input_dics['force_waveform']:
-                client_fdsn.get_waveforms(st_avail[0], st_avail[1],
-                                          st_avail[2], st_avail[3],
-                                          t_start, t_end,
-                                          filename=os.path.join(target_path,
-                                                                'raw',
-                                                                st_id))
+                waveforms_path2write = os.path.join(target_path, 'raw', st_id)
+                if req_cli.lower() in ["iris-federator", "eida-routing"]:
+                    dl_waveform = \
+                        client_fdsn.get_waveforms(
+                            network=st_avail[0],
+                            station=st_avail[1],
+                            location=st_avail[2],
+                            channel=st_avail[3],
+                            starttime=t_start,
+                            endtime=t_end)
+                    if len(dl_waveform) > 0:
+                        dl_waveform.write(waveforms_path2write, format='mseed')
+                    else:
+                        raise Exception
+
+                else:
+                    client_fdsn.get_waveforms(network=st_avail[0],
+                                              station=st_avail[1],
+                                              location=st_avail[2],
+                                              channel=st_avail[3],
+                                              starttime=t_start,
+                                              endtime=t_end,
+                                              filename=waveforms_path2write)
                 identifier += 10
                 print('%s -- %s -- saving waveform for: %s  ---> DONE' \
                       % (info_station, req_cli, st_id))
@@ -327,15 +339,31 @@ def fdsn_download_core(st_avail, event, input_dics, target_path,
             if (not os.path.isfile(os.path.join(target_path, 'resp',
                                                 'STXML.' + st_id))) \
                     or input_dics['force_response']:
-                client_fdsn.get_stations(network=st_avail[0],
-                                         station=st_avail[1],
-                                         location=st_avail[2],
-                                         channel=st_avail[3],
-                                         starttime=t_start, endtime=t_end,
-                                         filename=os.path.join(
-                                             target_path, 'resp',
-                                             'STXML.%s' % st_id),
-                                         level='response')
+                resp_path2write = os.path.join(target_path, 'resp', 'STXML.%s' % st_id)
+                if req_cli.lower() in ["iris-federator", "eida-routing"]:
+                    dl_response = \
+                        client_fdsn.get_stations(
+                            network=st_avail[0],
+                            station=st_avail[1],
+                            location=st_avail[2],
+                            channel=st_avail[3],
+                            starttime=t_start,
+                            endtime=t_end,
+                            level='response')
+                    if len(dl_response) > 0:
+                        dl_response.write(resp_path2write, format="stationxml")
+                    else:
+                        raise Exception
+
+                else:
+                    client_fdsn.get_stations(network=st_avail[0],
+                                             station=st_avail[1],
+                                             location=st_avail[2],
+                                             channel=st_avail[3],
+                                             starttime=t_start,
+                                             endtime=t_end,
+                                             filename=resp_path2write,
+                                             level='response')
                 identifier += 100
                 print("%s -- %s -- saving response for: %s  ---> DONE" \
                       % (info_station, req_cli, st_id))
@@ -450,270 +478,6 @@ def fdsn_bulk_request(target_path, req_cli, input_dics):
                                       bulk_st.stats['channel'])),
                       'MSEED')
 
-# ##################### arc_waveform ###############################
-
-
-def arc_waveform(stas_avail, event, input_dics, req_cli, info_event):
-    """
-    get Waveforms, StationXML files and meta-data from ArcLink
-    :param stas_avail:
-    :param event:
-    :param input_dics:
-    :param req_cli:
-    :param info_event:
-    :return:
-    """
-    eventpath = os.path.join(input_dics['datapath'])
-    target_path = os.path.join(eventpath, event['event_id'])
-
-    arc_serial_parallel(stas_avail, event, input_dics, target_path,
-                        req_cli, info_event)
-
-# ##################### arc_serial_parallel ##################################
-
-
-def arc_serial_parallel(stas_avail, event, input_dics, target_path,
-                        req_cli, info_event):
-    """
-    retrieving data from ArcLink
-    :param stas_avail:
-    :param event:
-    :param input_dics:
-    :param target_path:
-    :param req_cli:
-    :param info_event:
-    :return:
-    """
-    print('%s -- event: %s' % (req_cli, target_path))
-
-    client_arclink = Client_arclink(user=input_dics['username_arclink'],
-                                    host=input_dics['host_arclink'],
-                                    port=input_dics['port_arclink'],
-                                    password=input_dics['password_arclink'],
-                                    timeout=input_dics['arc_wave_timeout'])
-    client_syngine = Client_syngine()
-
-    if input_dics['req_parallel']:
-        par_jobs = []
-        st_counter = 0
-        for st_avail in stas_avail:
-            st_counter += 1
-            info_station = '[%s-%s/%s]' % (info_event, st_counter,
-                                           len(stas_avail))
-            p = multiprocessing.Process(target=arc_download_core,
-                                        args=(st_avail, event,
-                                              input_dics, target_path,
-                                              client_arclink, client_syngine,
-                                              req_cli,
-                                              info_station))
-            par_jobs.append(p)
-
-        sub_par_jobs = []
-        for l in range(len(par_jobs)):
-            counter = input_dics['req_np']
-            while counter >= input_dics['req_np']:
-                counter = 0
-                for ll in range(len(sub_par_jobs)):
-                    if par_jobs[sub_par_jobs[ll]].is_alive():
-                        counter += 1
-            par_jobs[l].start()
-            sub_par_jobs.append(l)
-
-        counter = input_dics['req_np']
-        while counter > 0:
-            counter = 0
-            for ll in range(len(par_jobs)):
-                if par_jobs[ll].is_alive():
-                    counter += 1
-    else:
-        st_counter = 0
-        for st_avail in stas_avail:
-            st_counter += 1
-            info_station = '[%s-%s/%s]' % (info_event, st_counter,
-                                           len(stas_avail))
-            arc_download_core(st_avail, event, input_dics, target_path,
-                              client_arclink, client_syngine,
-                              req_cli, info_station)
-
-# ##################### arc_download_core ##################################
-
-
-def arc_download_core(st_avail, event, input_dics, target_path,
-                      client_arclink, client_syngine, req_cli, info_station):
-    """
-    downloading the waveforms, reponse files (StationXML) and metadata
-    this function should be normally called by some higher-level functions
-    :param st_avail:
-    :param event:
-    :param input_dics:
-    :param target_path:
-    :param client_arclink:
-    :param client_syngine:
-    :param req_cli:
-    :param info_station:
-    :return:
-    """
-    dummy = 'initializing'
-
-    t11 = datetime.now()
-    identifier = 0
-    st_id = '%s.%s.%s.%s' % (st_avail[0], st_avail[1],
-                             st_avail[2], st_avail[3])
-    try:
-        if st_avail[2] == '--' or st_avail[2] == '  ':
-                st_avail[2] = ''
-
-        if input_dics['cut_time_phase']:
-            t_start, t_end = calculate_time_phase(event, st_avail)
-        else:
-            t_start = event['t1']
-            t_end = event['t2']
-
-        if input_dics['min_azi'] or input_dics['max_azi'] or \
-                input_dics['min_epi'] or input_dics['max_epi']:
-            dist, azi, bazi = gps2DistAzimuth(event['latitude'],
-                                              event['longitude'],
-                                              float(st_avail[4]),
-                                              float(st_avail[5]))
-            epi_dist = dist/111.194/1000.
-            if input_dics['min_epi']:
-                if epi_dist < input_dics['min_epi']:
-                    raise Exception('%s out of epi range: %s'
-                                    % (st_id, epi_dist))
-            if input_dics['max_epi']:
-                if epi_dist > input_dics['max_epi']:
-                    raise Exception('%s out of epi range: %s'
-                                    % (st_id, epi_dist))
-            if input_dics['min_azi']:
-                if azi < input_dics['min_azi']:
-                    raise Exception('%s outo f Azimuth range: %s'
-                                    % (st_id, azi))
-            if input_dics['max_azi']:
-                if azi > input_dics['max_azi']:
-                    raise Exception('%s out of Azimuth range: %s'
-                                    % (st_id, azi))
-
-        if input_dics['waveform']:
-            dummy = 'waveform'
-            if (not os.path.isfile(os.path.join(target_path, 'raw', st_id))) \
-                    or input_dics['force_waveform']:
-
-                if hasattr(client_arclink, 'save_waveforms'):
-                    client_arclink.save_waveforms(os.path.join(target_path,
-                                                               'raw', st_id),
-                                                  st_avail[0], st_avail[1],
-                                                  st_avail[2], st_avail[3],
-                                                  t_start, t_end)
-                elif hasattr(client_arclink, 'saveWaveform'):
-                    client_arclink.saveWaveform(os.path.join(target_path,
-                                                             'raw', st_id),
-                                                st_avail[0], st_avail[1],
-                                                st_avail[2], st_avail[3],
-                                                t_start, t_end)
-                identifier += 10
-                print('%s -- %s -- saving waveform for: %s  ---> DONE' \
-                      % (info_station, req_cli, st_id))
-            else:
-                identifier += 1
-
-        if input_dics['response']:
-            dummy = 'response'
-            if (not os.path.isfile(os.path.join(target_path, 'resp',
-                                                'STXML.' + st_id))) \
-                    or input_dics['force_response']:
-                if (not os.path.isfile(os.path.join(target_path, 'resp',
-                                                    'DATALESS.' + st_id))) \
-                        or input_dics['force_response']:
-                    if hasattr(client_arclink, 'save_response'):
-                        client_arclink.save_response(
-                            os.path.join(target_path, 'resp',
-                                         'DATALESS.%s' % st_id),
-                            st_avail[0], st_avail[1], st_avail[2], st_avail[3],
-                            t_start, t_end)
-                    if hasattr(client_arclink, 'saveResponse'):
-                        client_arclink.saveResponse(
-                            os.path.join(target_path, 'resp',
-                                         'DATALESS.%s' % st_id),
-                            st_avail[0], st_avail[1], st_avail[2], st_avail[3],
-                            t_start, t_end)
-                    identifier += 100
-                    print("%s -- %s -- saving response for: %s  ---> DONE" \
-                          % (info_station, req_cli, st_id))
-                else:
-                    identifier += 1
-            else:
-                identifier += 1
-
-        if input_dics['syngine']:
-            dummy = 'syngine_waveform'
-            syn_dirpath = os.path.join(
-                target_path, 'syngine_%s' % input_dics['syngine_bg_model'])
-            if not os.path.isdir(syn_dirpath):
-                os.makedirs(syn_dirpath)
-            if (not os.path.isfile(os.path.join(syn_dirpath, st_id)))\
-                    or input_dics['force_waveform']:
-
-                if input_dics['syngine_geocentric_lat']:
-                    rcvlatitude = geocen_calc(float(st_avail[4]))
-                    evlatitude = geocen_calc(event['latitude'])
-                else:
-                    rcvlatitude = float(st_avail[4])
-                    evlatitude = event['latitude']
-
-                if not event['focal_mechanism']:
-                    syngine_momenttensor = None
-                else:
-                    syngine_momenttensor = event['focal_mechanism']
-
-                # XXX some other arguments
-                # sourcedoublecouple=None,
-                # dt=None
-                # kernelwidth=None
-                # sourceforce=None
-                # label=None
-                syn_st = client_syngine.get_waveforms(
-                    model=input_dics['syngine_bg_model'],
-                    receiverlatitude=rcvlatitude,
-                    receiverlongitude=float(st_avail[5]),
-                    networkcode=st_avail[0],
-                    stationcode=st_avail[1],
-                    sourcelatitude=evlatitude,
-                    sourcelongitude=event['longitude'],
-                    sourcedepthinmeters=float(event['depth'])*1000.,
-                    origintime=event['datetime'],
-                    components=st_avail[3][-1],
-                    units=input_dics['syngine_units'],
-                    sourcemomenttensor=syngine_momenttensor,
-                    starttime=t_start,
-                    endtime=t_end)[0]
-
-                syn_st.stats.location = st_avail[2]
-                syn_st.stats.channel = st_avail[3]
-                syn_st.write(os.path.join(syn_dirpath, st_id),
-                             format='mseed')
-
-                identifier += 1000
-                print('%s -- %s -- saving syngine for: %s  ---> DONE' \
-                      % (info_station, req_cli, st_id))
-            else:
-                identifier += 1
-
-        # if identifier in [0, 2, 10, 11, 100]:
-        #     raise Exception("CODE: %s will not be registered! (666)"
-        #                     % identifier)
-        t22 = datetime.now()
-    except Exception as error:
-        t22 = datetime.now()
-
-        if len(st_avail) != 0:
-            ee = '%s -- %s -- %s -- %s\n' % (req_cli, dummy, st_id, error)
-        else:
-            ee = '%s: There is no available station for this event.' % req_cli
-        Exception_file = open(os.path.join(target_path,
-                                           'info', 'exception'), 'at+')
-        Exception_file.writelines(ee)
-        Exception_file.close()
-
 # ##################### update_sta_ev_file ##################################
 
 
@@ -726,8 +490,8 @@ def update_sta_ev_file(target_path, event):
     """
     avail_arr = np.loadtxt(os.path.join(target_path, 'info',
                                         'availability.txt'),
-                           delimiter=',', dtype=bytes, ndmin=2).astype(np.str)
-    avail_arr = avail_arr.astype(np.object)
+                           delimiter=',', dtype=bytes, ndmin=2).astype(str)
+    avail_arr = avail_arr.astype(object)
     sta_ev_add = os.path.join(target_path, 'info', 'station_event')
     sta_ev_fio = open(sta_ev_add, 'wt+')
 
