@@ -100,8 +100,9 @@ def print_data_sources():
     print("list of all shortcut names")
     print("--------------------------\n")
     for key in sorted(URL_MAPPINGS.keys()):
-        print("{0:<7} {1}".format(key,  URL_MAPPINGS[key]))
-    print("ARCLINK")
+        print("{0:<15} {1}".format(key,  URL_MAPPINGS[key]))
+    print("iris-federator")
+    print("eida-routing")
     print("\n============================================================")
     print("This is the list of all shortcut names which can be used for")
     print("--data_source option.")
@@ -528,8 +529,8 @@ def calculate_time_phase(event, sta, bg_model='iasp91'):
         except:
             time_ph = 0
     else:
-        try:
-            for ph in phase_list:
+        for ph in phase_list:
+            try:
                 tt = tau_bg.get_travel_times(evdp, dist,
                                              phase_list=[ph])[0].time
                 if not tt:
@@ -538,11 +539,12 @@ def calculate_time_phase(event, sta, bg_model='iasp91'):
                 else:
                     time_ph = tt
                     break
-        except:
-            time_ph = 0
+            except:
+                time_ph = 0
 
     t_start = event['t1'] + time_ph
     t_end = event['t2'] + time_ph
+
     return t_start, t_end
 
 # ##################### plot_filter_station ###############################
